/** @file common.h
 *
 *  Note: definitions which comes from H3C
 */


#include <math.h>
#include <stdlib.h>
#include "postgres.h"
#ifndef H3C_COMMON_H
#define H3C_COMMON_H

#if 1
/* If You have not specified the H3C_INT4 then use long */
#ifndef H3C_INT4 

#ifndef H3C_INT8

#ifndef h3c_ipix_t
typedef long h3c_ipix_t;

#endif

#else

#ifndef h3c_ipix_t
/*#define h3c_ipix_t long long 
  typedef long long h3c_ipix_t ;*/
typedef int64 h3c_ipix_t ;
#endif /* h3c_ipix_t */

#endif /* H3C_INT8 */

#else 

#ifndef h3c_ipix_t
/*#define h3c_ipix_t long int
  typedef unsigned long int h3c_ipix_t;*/
typedef uint32 h3c_ipix_t;
#endif /* h3c_ipix_t */


#endif /* H3C_INT4 */ 

#else
/* Currently Helpix lib deals only with long 
 * Use Healpix_Base2 for int64 but it misses class members query_disc...
 */
typedef long h3c_ipix_t;
#endif


#ifndef H3C_LONG_DOUBLE
typedef double h3c_coord_t;
#define H3C_HALF 0.5
#define H3C_PI 3.1415926535897932384626433832795028841968
#define H3C_2PI 6.2831853071795864769252867665590057683936
#define H3C_INV_2PI 0.1591549430918953357688837633725143620345
#define H3C_PI_2 1.5707963267948966192313216916397514420984
#define H3C_DEGRA 0.0174532925199432957692369076848861271344
#define H3C_RADEG 57.2957795130823208767981548141051703324122
#define H3C_LG2 0.6931471805599453094172321214581765680755

#else /* H3C_LONG_DOUBLE */
typedef long double h3c_coord_t;
#define H3C_HALF 0.5L
#define H3C_PI 3.1415926535897932384626433832795028841968L
#define H3C_2PI 6.2831853071795864769252867665590057683936L
#define H3C_INV_2PI 0.1591549430918953357688837633725143620345L
#define H3C_PI_2 1.5707963267948966192313216916397514420984L
#define H3C_DEGRA 0.0174532925199432957692369076848861271344L
#define H3C_RADEG 57.2957795130823208767981548141051703324122L
#define H3C_LG2 0.6931471805599453094172321214581765680755L

#endif /* H3C_LONG_DOUBLE */

#define H3C_DISJUNCT 0	/* disjunct areas */

#define H3C_MAX_N_POLY_VERTEX 100 /* Maximal number of vertices in the polygon */

typedef struct
{
	int n;
	h3c_coord_t *ra;	/* array of RAs of vertices */
	h3c_coord_t *dec;	/* array of DECs of vertices */
	h3c_coord_t *x;		/* array of X coords on the cube face of vertices */
	h3c_coord_t *y;		/* array of Y coords on the cube face of vertices */
	h3c_coord_t *ax;	/* array of x projections of the edge between vertices */
	h3c_coord_t *ay;	/* array of y projections of the edge between vertices */
} h3c_poly;


#ifdef __cplusplus
extern "C" {
#endif
	int h3c_check_sphere_point_in_poly(/*struct h3c_prm *hprm,*/ int n,
					   h3c_coord_t in_ra[], h3c_coord_t in_dec[],
					   h3c_coord_t ra0, h3c_coord_t dec0);
	int h3c_check_sphere_point_in_poly_convex(int n,
					   h3c_coord_t in_ra[], h3c_coord_t in_dec[],
                	                   h3c_coord_t ra0, h3c_coord_t dec0);
	void h3c_poly_center(int, h3c_coord_t *, h3c_coord_t *, h3c_coord_t *);
#ifdef __cplusplus
}
#endif

#endif
