BEGIN;
SET search_path = public;

CREATE OR REPLACE FUNCTION h3c_version() RETURNS FLOAT
	AS  '$libdir/h3c', 'pgh3c_version'
        LANGUAGE C IMMUTABLE STRICT;
CREATE OR REPLACE FUNCTION h3c_ang2ipix(double precision, double precision, integer)
        RETURNS bigint
        AS '$libdir/h3c', 'pgh3c_ang2ipix'
        LANGUAGE C IMMUTABLE STRICT;
COMMENT ON FUNCTION h3c_ang2ipix (double precision, double precision, integer)
	IS 'Function converting Ra and Dec to the H3C ipix value';

CREATE OR REPLACE FUNCTION h3c_ang2ipix(double precision, double precision)
        RETURNS bigint
        AS '$libdir/h3c', 'pgh3c_ang2ipix_default'
        LANGUAGE C IMMUTABLE STRICT;
COMMENT ON FUNCTION h3c_ang2ipix (double precision, double precision)
	IS 'Function converting Ra and Dec to the H3C ipix value';

CREATE OR REPLACE FUNCTION h3c_ipix2ang(ipix bigint, integer)
        RETURNS double precision[]
        AS '$libdir/h3c', 'pgh3c_ipix2ang'
        LANGUAGE C IMMUTABLE STRICT;
COMMENT ON FUNCTION h3c_ipix2ang (bigint, integer)
	IS 'Function converting the H3C ipix value to Ra, Dec (the center)';

CREATE OR REPLACE FUNCTION h3c_ipix2ang(ipix bigint)
        RETURNS double precision[]
        AS '$libdir/h3c', 'pgh3c_ipix2ang_default'
        LANGUAGE C IMMUTABLE STRICT;
COMMENT ON FUNCTION h3c_ipix2ang(bigint)
	IS 'Function converting the H3C ipix value to Ra, Dec (the center)';


CREATE OR REPLACE FUNCTION h3c_disk_ipix(IN double precision, IN double precision, IN double precision, IN integer, 
    OUT f bigint)
    RETURNS SETOF bigint
    AS '$libdir/h3c', 'pgh3c_disk_ipix'
    LANGUAGE C IMMUTABLE STRICT;

CREATE OR REPLACE FUNCTION h3c_disk_ipix(IN double precision, IN double precision, IN double precision,
    OUT f bigint)
    RETURNS SETOF bigint
    AS '$libdir/h3c', 'pgh3c_disk_ipix_default'
    LANGUAGE C IMMUTABLE STRICT;

/*
CREATE OR REPLACE FUNCTION h3c_pixarea(ipix bigint, depth int)
        RETURNS double precision
        AS '$libdir/h3c', 'pgh3c_pixarea'
        LANGUAGE C IMMUTABLE STRICT;
COMMENT ON FUNCTION h3c_pixarea (bigint, int )
	IS 'Function returning the area of the pixel containing ipix being located at certain depth in the quadtree';

CREATE OR REPLACE FUNCTION h3c_ipixcenter(ra double precision, decl double precision, int)
        RETURNS bigint
        AS
   'SELECT ((h3c_ang2ipix($1,$2))>>((2*$3))<<((2*$3))) +
			((1::bigint)<<(2*($3-1))) -1'
	LANGUAGE SQL;
*/

CREATE OR REPLACE FUNCTION h3c_dist(ra1 double precision, dec1 double precision,
				ra2 double precision, dec2 double precision)
        RETURNS double precision
        AS '$libdir/h3c', 'pgh3c_dist'
        LANGUAGE C IMMUTABLE STRICT;
COMMENT ON FUNCTION h3c_dist(double precision, double precision,
			double precision, double precision)
	IS 'Function h3c_dist(ra1, dec1, ra2, dec2) computing the distance between points (ra1, dec1) and (ra2, dec2)';

CREATE OR REPLACE FUNCTION h3c_sindist(double precision, double precision,
                                       double precision, double precision)
        RETURNS double precision
        AS '$libdir/h3c', 'pgh3c_sindist'
        LANGUAGE C IMMUTABLE STRICT;


CREATE OR REPLACE FUNCTION h3c_radial_query_it(IN double precision, IN double precision, IN double precision, IN integer, IN integer,
    OUT f bigint)
    RETURNS bigint
    AS '$libdir/h3c', 'pgh3c_radial_query_it'
    LANGUAGE C IMMUTABLE STRICT;

CREATE OR REPLACE FUNCTION h3c_radial_query_it(IN double precision, IN double precision, IN double precision, IN integer,
    OUT f bigint)
    RETURNS bigint
    AS '$libdir/h3c', 'pgh3c_radial_query_it_default'
    LANGUAGE C IMMUTABLE STRICT;

/*CREATE OR REPLACE FUNCTION h3c_radial_query2(
                  double precision, double precision,
                  double precision, double precision, double precision)
                                         returns boolean as 'SELECT
(h3c_ang2ipix($1,$2) in (select h3c_disk_ipix($3,$4,$5)))
AND h3c_sindist($1,$2,$3,$4)<POW(SIN(RADIANS($5)/2),2)
' LANGUAGE SQL IMMUTABLE; index is not took */

CREATE OR REPLACE FUNCTION h3c_nearby_it(IN double precision, IN double precision, IN double precision, IN integer, IN integer,
    OUT f bigint)
    RETURNS bigint
    AS '$libdir/h3c', 'pgh3c_nearby_it'
    LANGUAGE C IMMUTABLE STRICT;

CREATE OR REPLACE FUNCTION h3c_nearby_it(IN double precision, IN double precision, IN double precision, IN integer,
    OUT f bigint)
    RETURNS bigint
    AS '$libdir/h3c', 'pgh3c_nearby_it_default'
    LANGUAGE C IMMUTABLE STRICT;

CREATE OR REPLACE FUNCTION h3c_join_symetric(
                  double precision, double precision,
                  double precision, double precision, double precision, integer)
                                         returns boolean as 'SELECT((
(h3c_ang2ipix($3,$4,$6)>=h3c_nearby_it($1,$2,$5,0,$6) AND h3c_ang2ipix($3,$4,$6)<=h3c_nearby_it($1,$2,$5,1,$6)) OR
(h3c_ang2ipix($3,$4,$6)>=h3c_nearby_it($1,$2,$5,2,$6) AND h3c_ang2ipix($3,$4,$6)<=h3c_nearby_it($1,$2,$5,3,$6)) OR
(h3c_ang2ipix($3,$4,$6)>=h3c_nearby_it($1,$2,$5,4,$6) AND h3c_ang2ipix($3,$4,$6)<=h3c_nearby_it($1,$2,$5,5,$6)) OR
(h3c_ang2ipix($3,$4,$6)>=h3c_nearby_it($1,$2,$5,6,$6) AND h3c_ang2ipix($3,$4,$6)<=h3c_nearby_it($1,$2,$5,7,$6)) 
)
 AND (
(h3c_ang2ipix($1,$2,$6)>=h3c_nearby_it($3,$4,$5,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_nearby_it($3,$4,$5,1,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_nearby_it($3,$4,$5,2,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_nearby_it($3,$4,$5,3,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_nearby_it($3,$4,$5,4,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_nearby_it($3,$4,$5,5,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_nearby_it($3,$4,$5,6,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_nearby_it($3,$4,$5,7,$6)) 
)
 AND h3c_sindist($1,$2,$3,$4)<POW(SIN(RADIANS($5)/2),2)
)
' LANGUAGE SQL IMMUTABLE;

CREATE OR REPLACE FUNCTION h3c_join_symetric(
                  double precision, double precision,
                  double precision, double precision, double precision)
                                         returns boolean as 'SELECT((
(h3c_ang2ipix($3,$4)>=h3c_nearby_it($1,$2,$5,0) AND h3c_ang2ipix($3,$4)<=h3c_nearby_it($1,$2,$5,1)) OR
(h3c_ang2ipix($3,$4)>=h3c_nearby_it($1,$2,$5,2) AND h3c_ang2ipix($3,$4)<=h3c_nearby_it($1,$2,$5,3)) OR
(h3c_ang2ipix($3,$4)>=h3c_nearby_it($1,$2,$5,4) AND h3c_ang2ipix($3,$4)<=h3c_nearby_it($1,$2,$5,5)) OR
(h3c_ang2ipix($3,$4)>=h3c_nearby_it($1,$2,$5,6) AND h3c_ang2ipix($3,$4)<=h3c_nearby_it($1,$2,$5,7)) 
)
AND (
(h3c_ang2ipix($1,$2)>=h3c_nearby_it($3,$4,$5,0) AND h3c_ang2ipix($1,$2)<=h3c_nearby_it($3,$4,$5,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_nearby_it($3,$4,$5,2) AND h3c_ang2ipix($1,$2)<=h3c_nearby_it($3,$4,$5,3)) OR
(h3c_ang2ipix($1,$2)>=h3c_nearby_it($3,$4,$5,4) AND h3c_ang2ipix($1,$2)<=h3c_nearby_it($3,$4,$5,5)) OR
(h3c_ang2ipix($1,$2)>=h3c_nearby_it($3,$4,$5,6) AND h3c_ang2ipix($1,$2)<=h3c_nearby_it($3,$4,$5,7)) 
)
 AND h3c_sindist($1,$2,$3,$4)<POW(SIN(RADIANS($5)/2),2)
)
' LANGUAGE SQL IMMUTABLE;

CREATE OR REPLACE FUNCTION h3c_join(
                  double precision, double precision,
                  double precision, double precision, double precision, integer)
                                         returns boolean as 'SELECT((
(h3c_ang2ipix($3,$4,$6)>=h3c_nearby_it($1,$2,$5,0,$6) AND h3c_ang2ipix($3,$4,$6)<=h3c_nearby_it($1,$2,$5,1,$6)) OR
(h3c_ang2ipix($3,$4,$6)>=h3c_nearby_it($1,$2,$5,2,$6) AND h3c_ang2ipix($3,$4,$6)<=h3c_nearby_it($1,$2,$5,3,$6)) OR
(h3c_ang2ipix($3,$4,$6)>=h3c_nearby_it($1,$2,$5,4,$6) AND h3c_ang2ipix($3,$4,$6)<=h3c_nearby_it($1,$2,$5,5,$6)) OR
(h3c_ang2ipix($3,$4,$6)>=h3c_nearby_it($1,$2,$5,6,$6) AND h3c_ang2ipix($3,$4,$6)<=h3c_nearby_it($1,$2,$5,7,$6)) 
)
 AND h3c_sindist($1,$2,$3,$4)<POW(SIN(RADIANS($5)/2),2)
)
' LANGUAGE SQL IMMUTABLE;

CREATE OR REPLACE FUNCTION h3c_join(
                  double precision, double precision,
                  double precision, double precision, double precision)
                                         returns boolean as 'SELECT((
(h3c_ang2ipix($3,$4)>=h3c_nearby_it($1,$2,$5,0) AND h3c_ang2ipix($3,$4)<=h3c_nearby_it($1,$2,$5,1)) OR
(h3c_ang2ipix($3,$4)>=h3c_nearby_it($1,$2,$5,2) AND h3c_ang2ipix($3,$4)<=h3c_nearby_it($1,$2,$5,3)) OR
(h3c_ang2ipix($3,$4)>=h3c_nearby_it($1,$2,$5,4) AND h3c_ang2ipix($3,$4)<=h3c_nearby_it($1,$2,$5,5)) OR
(h3c_ang2ipix($3,$4)>=h3c_nearby_it($1,$2,$5,6) AND h3c_ang2ipix($3,$4)<=h3c_nearby_it($1,$2,$5,7)) 
)
 AND h3c_sindist($1,$2,$3,$4)<POW(SIN(RADIANS($5)/2),2)
)
' LANGUAGE SQL IMMUTABLE;

CREATE OR REPLACE FUNCTION h3c_dist_ipix(bigint, bigint)
        RETURNS double precision
        AS '$libdir/h3c', 'pgh3c_dist_ipix'
        LANGUAGE C IMMUTABLE STRICT;

CREATE OR REPLACE FUNCTION h3c_radial_query(
                  double precision, double precision,
                  double precision, double precision, double precision)
                                         returns boolean as 'SELECT((
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,2) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,3)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,4) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,5)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,6) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,7)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,8) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,9)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,10) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,11)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,12) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,13)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,14) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,15)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,16) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,17)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,18) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,19)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,20) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,21)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,22) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,23)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,24) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,25)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,26) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,27)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,28) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,29)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,30) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,31)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,32) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,33)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,34) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,35)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,36) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,37)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,38) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,39)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,40) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,41)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,42) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,43)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,44) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,45)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,46) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,47)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,48) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,49)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,50) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,51)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,52) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,53)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,54) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,55)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,56) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,57)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,58) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,59)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,60) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,61)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,62) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,63)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,64) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,65)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,66) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,67)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,68) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,69)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,70) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,71)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,72) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,73)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,74) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,75)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,76) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,77)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,78) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,79)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,80) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,81)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,82) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,83)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,84) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,85)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,86) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,87)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,88) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,89)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,90) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,91)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,92) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,93)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,94) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,95)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,96) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,97)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,98) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,99)) 
) /*OR (
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,0,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,1,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,2,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,3,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,4,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,5,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,6,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,7,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,8,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,9,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,10,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,11,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,12,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,13,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,14,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,15,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,16,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,17,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,18,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,19,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,20,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,21,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,22,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,23,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,24,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,25,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,26,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,27,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,28,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,29,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,30,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,31,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,32,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,33,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,34,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,35,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,36,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,37,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,38,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,39,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,40,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,41,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,42,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,43,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,44,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,45,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,46,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,47,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,48,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,49,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,50,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,51,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,52,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,53,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,54,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,55,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,56,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,57,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,58,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,59,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,60,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,61,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,62,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,63,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,64,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,65,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,66,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,67,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,68,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,69,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,70,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,71,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,72,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,73,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,74,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,75,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,76,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,77,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,78,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,79,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,80,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,81,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,82,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,83,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,84,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,85,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,86,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,87,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,88,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,89,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,90,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,91,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,92,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,93,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,94,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,95,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,96,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,97,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_radial_query_it($3,$4,$5,98,0) AND h3c_ang2ipix($1,$2)<=h3c_radial_query_it($3,$4,$5,99,0))
)*/
 AND h3c_sindist($1,$2,$3,$4)<POW(SIN(RADIANS($5)/2),2)
)
' LANGUAGE SQL IMMUTABLE;

CREATE OR REPLACE FUNCTION h3c_radial_query(
                  double precision, double precision,
                  double precision, double precision, double precision, integer)
                                         returns boolean as 'SELECT((
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,1,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,2,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,3,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,4,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,5,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,6,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,7,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,8,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,9,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,10,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,11,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,12,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,13,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,14,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,15,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,16,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,17,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,18,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,19,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,20,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,21,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,22,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,23,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,24,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,25,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,26,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,27,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,28,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,29,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,30,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,31,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,32,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,33,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,34,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,35,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,36,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,37,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,38,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,39,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,40,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,41,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,42,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,43,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,44,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,45,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,46,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,47,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,48,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,49,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,50,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,51,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,52,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,53,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,54,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,55,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,56,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,57,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,58,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,59,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,60,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,61,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,62,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,63,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,64,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,65,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,66,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,67,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,68,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,69,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,70,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,71,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,72,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,73,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,74,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,75,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,76,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,77,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,78,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,79,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,80,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,81,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,82,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,83,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,84,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,85,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,86,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,87,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,88,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,89,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,90,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,91,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,92,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,93,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,94,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,95,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,96,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,97,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,98,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,99,$6))
) /*OR (
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,0,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,1,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,2,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,3,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,4,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,5,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,6,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,7,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,8,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,9,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,10,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,11,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,12,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,13,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,14,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,15,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,16,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,17,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,18,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,19,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,20,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,21,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,22,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,23,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,24,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,25,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,26,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,27,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,28,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,29,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,30,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,31,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,32,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,33,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,34,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,35,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,36,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,37,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,38,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,39,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,40,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,41,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,42,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,43,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,44,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,45,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,46,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,47,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,48,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,49,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,50,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,51,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,52,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,53,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,54,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,55,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,56,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,57,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,58,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,59,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,60,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,61,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,62,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,63,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,64,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,65,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,66,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,67,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,68,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,69,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,70,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,71,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,72,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,73,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,74,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,75,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,76,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,77,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,78,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,79,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,80,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,81,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,82,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,83,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,84,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,85,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,86,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,87,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,88,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,89,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,90,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,91,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,92,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,93,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,94,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,95,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,96,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,97,0,$6)) OR
(h3c_ang2ipix($1,$2,$6)>=h3c_radial_query_it($3,$4,$5,98,0,$6) AND h3c_ang2ipix($1,$2,$6)<=h3c_radial_query_it($3,$4,$5,99,0,$6))
)*/
 AND h3c_sindist($1,$2,$3,$4)<POW(SIN(RADIANS($5)/2),2)
)
' LANGUAGE SQL IMMUTABLE;

CREATE OR REPLACE FUNCTION h3c_radial_query(bigint,
                  double precision, double precision, double precision)
                                         returns boolean as '
SELECT h3c_radial_query((h3c_ipix2ang($1))[1],(h3c_ipix2ang($1))[2],$2,$3,$4)
' LANGUAGE SQL IMMUTABLE;

CREATE OR REPLACE FUNCTION h3c_radial_query(bigint, bigint, double precision)
                                         returns boolean as '
SELECT h3c_radial_query((h3c_ipix2ang($1))[1],(h3c_ipix2ang($1))[2],(h3c_ipix2ang($2))[1],(h3c_ipix2ang($2))[2],$3)
' LANGUAGE SQL IMMUTABLE;

CREATE OR REPLACE FUNCTION h3c_in_ellipse(ra0 double precision, dec0 double precision,
					ra_ell double precision, dec_ell double precision,
					maj_ax double precision, axis_ratio double precision,
					pa double precision)
        RETURNS boolean
        AS '$libdir/h3c', 'pgh3c_in_ellipse'
        LANGUAGE C IMMUTABLE STRICT;

/*

CREATE OR REPLACE FUNCTION h3c_ellipse_nearby_it(double precision, double precision, 
		double precision, double precision, double precision, integer)
        RETURNS bigint
        AS '$libdir/h3c', 'pgh3c_ellipse_nearby_it'
        LANGUAGE C IMMUTABLE STRICT;

CREATE OR REPLACE FUNCTION h3c_in_ellipse(ra0 double precision, dec0 double precision,
					ra_ell double precision, dec_ell double precision,
					maj_ax double precision, axis_ratio double precision,
					pa double precision)
        RETURNS boolean
        AS '$libdir/h3c', 'pgh3c_in_ellipse'
        LANGUAGE C IMMUTABLE STRICT;


CREATE OR REPLACE FUNCTION h3c_ellipse_query_it(ra_ell double precision,
												dec_ell double precision,
												majax double precision,
												axis_ratio double precision,
												PA double precision,
												iteration integer,
												full_flag integer)
	RETURNS bigint
	AS '$libdir/h3c', 'pgh3c_ellipse_query_it'
LANGUAGE C IMMUTABLE STRICT;

*/

CREATE OR REPLACE FUNCTION h3c_poly_query_it(double precision[], integer, integer)
        RETURNS bigint
        AS '$libdir/h3c', 'pgh3c_poly_query_it'
        LANGUAGE C IMMUTABLE STRICT;

CREATE OR REPLACE FUNCTION h3c_poly_query_it(double precision[], integer)
        RETURNS bigint
        AS '$libdir/h3c', 'pgh3c_poly_query_it_default'
        LANGUAGE C IMMUTABLE STRICT;

CREATE OR REPLACE FUNCTION h3c_in_poly(double precision, double precision,
				       double precision[])
        RETURNS boolean
        AS '$libdir/h3c', 'pgh3c_in_poly_convex'
        LANGUAGE C IMMUTABLE STRICT;

CREATE OR REPLACE FUNCTION h3c_in_poly_convex(double precision, double precision,
				       double precision[])
        RETURNS boolean
        AS '$libdir/h3c', 'pgh3c_in_poly_convex'
        LANGUAGE C IMMUTABLE STRICT;
/*
CREATE OR REPLACE FUNCTION h3c_in_box(double precision, double precision,
				      double precision, double precision,
				      double precision, double precision)
        RETURNS boolean
        AS '$libdir/h3c', 'pgh3c_in_box'
        LANGUAGE C IMMUTABLE STRICT;
*/
CREATE OR REPLACE FUNCTION h3c_poly_center(double precision[])
	RETURNS double precision[]
        AS '$libdir/h3c', 'pgh3c_poly_center'
        LANGUAGE C IMMUTABLE STRICT;

CREATE OR REPLACE FUNCTION h3c_circle_intersect_poly(double precision, double precision, double precision, double precision[])
	RETURNS boolean
        AS '$libdir/h3c', 'pgh3c_circle_intersect_poly'
        LANGUAGE C IMMUTABLE STRICT;

CREATE OR REPLACE FUNCTION h3c_poly_intersect_poly(double precision[], double precision[])
	RETURNS boolean
        AS '$libdir/h3c', 'pgh3c_poly_intersect_poly'
        LANGUAGE C IMMUTABLE STRICT;

/*CREATE OR REPLACE FUNCTION h3c_box_query_it(double precision, double precision, double precision, double precision, integer, integer)
        RETURNS bigint
        AS '$libdir/h3c', 'pgh3c_box_query_it'
        LANGUAGE C IMMUTABLE STRICT;

CREATE OR REPLACE FUNCTION h3c_box_query_it(double precision, double precision, double precision, double precision, integer)
        RETURNS bigint
        AS '$libdir/h3c', 'pgh3c_box_query_it_default'
        LANGUAGE C IMMUTABLE STRICT;
*/
CREATE OR REPLACE FUNCTION h3c_box_to_poly(double precision, double precision, double precision, double precision)
        RETURNS double precision[]
        AS  '$libdir/h3c', 'pgh3c_box_to_poly'
        LANGUAGE C IMMUTABLE STRICT;

/*
CREATE OR REPLACE FUNCTION h3c_ellipse_join(leftra double precision, leftdec double precision,
				rightra double precision, rightdec double precision,
				majoraxis double precision, axisratio double precision,
				pa double precision)
        RETURNS boolean AS
'
SELECT (((h3c_ang2ipix($3,$4)>=(h3c_ellipse_nearby_it($1,$2,$5,$6,$7,0))) AND (h3c_ang2ipix($3,$4)<=(h3c_ellipse_nearby_it($1,$2,$5,$6,$7,1))))
    OR ((h3c_ang2ipix($3,$4)>=(h3c_ellipse_nearby_it($1,$2,$5,$6,$7,2))) AND (h3c_ang2ipix($3,$4)<=(h3c_ellipse_nearby_it($1,$2,$5,$6,$7,3))))
    OR ((h3c_ang2ipix($3,$4)>=(h3c_ellipse_nearby_it($1,$2,$5,$6,$7,4))) AND (h3c_ang2ipix($3,$4)<=(h3c_ellipse_nearby_it($1,$2,$5,$6,$7,5))))
    OR ((h3c_ang2ipix($3,$4)>=(h3c_ellipse_nearby_it($1,$2,$5,$6,$7,6))) AND (h3c_ang2ipix($3,$4)<=(h3c_ellipse_nearby_it($1,$2,$5,$6,$7,7))))) 
    AND h3c_in_ellipse($3,$4,$1,$2,$5,$6,$7)
' LANGUAGE SQL IMMUTABLE;

CREATE OR REPLACE FUNCTION h3c_ellipse_query(
                ra_col double precision, dec_col double precision,
                ra_ell double precision, dec_ell double precision,
                majax double precision, axis_ratio double precision,
				PA double precision)
        RETURNS boolean AS 
'SELECT (
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,0,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,1,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,2,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,3,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,4,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,5,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,6,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,7,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,8,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,9,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,10,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,11,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,12,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,13,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,14,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,15,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,16,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,17,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,18,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,19,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,20,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,21,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,22,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,23,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,24,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,25,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,26,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,27,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,28,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,29,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,30,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,31,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,32,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,33,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,34,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,35,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,36,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,37,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,38,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,39,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,40,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,41,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,42,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,43,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,44,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,45,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,46,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,47,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,48,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,49,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,50,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,51,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,52,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,53,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,54,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,55,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,56,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,57,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,58,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,59,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,60,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,61,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,62,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,63,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,64,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,65,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,66,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,67,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,68,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,69,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,70,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,71,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,72,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,73,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,74,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,75,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,76,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,77,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,78,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,79,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,80,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,81,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,82,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,83,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,84,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,85,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,86,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,87,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,88,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,89,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,90,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,91,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,92,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,93,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,94,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,95,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,96,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,97,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,98,1) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,99,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,0,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,1,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,2,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,3,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,4,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,5,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,6,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,7,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,8,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,9,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,10,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,11,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,12,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,13,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,14,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,15,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,16,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,17,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,18,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,19,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,20,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,21,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,22,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,23,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,24,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,25,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,26,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,27,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,28,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,29,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,30,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,31,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,32,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,33,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,34,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,35,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,36,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,37,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,38,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,39,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,40,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,41,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,42,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,43,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,44,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,45,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,46,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,47,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,48,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,49,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,50,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,51,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,52,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,53,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,54,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,55,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,56,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,57,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,58,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,59,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,60,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,61,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,62,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,63,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,64,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,65,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,66,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,67,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,68,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,69,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,70,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,71,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,72,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,73,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,74,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,75,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,76,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,77,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,78,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,79,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,80,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,81,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,82,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,83,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,84,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,85,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,86,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,87,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,88,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,89,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,90,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,91,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,92,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,93,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,94,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,95,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,96,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,97,0)) OR
(h3c_ang2ipix($1,$2)>=h3c_ellipse_query_it($3,$4,$5,$6,$7,98,0) AND h3c_ang2ipix($1,$2)<h3c_ellipse_query_it($3,$4,$5,$6,$7,99,0)) 
)
AND h3c_in_ellipse($1,$2,$3,$4,$5,$6,$7)
' LANGUAGE SQL IMMUTABLE;



*/
CREATE OR REPLACE FUNCTION h3c_poly_query(
                double precision, double precision,
                double precision[])
                returns boolean as 'SELECT (
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,0) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,2) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,3)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,4) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,5)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,6) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,7)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,8) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,9)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,10) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,11)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,12) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,13)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,14) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,15)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,16) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,17)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,18) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,19)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,20) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,21)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,22) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,23)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,24) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,25)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,26) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,27)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,28) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,29)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,30) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,31)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,32) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,33)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,34) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,35)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,36) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,37)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,38) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,39)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,40) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,41)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,42) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,43)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,44) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,45)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,46) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,47)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,48) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,49)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,50) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,51)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,52) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,53)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,54) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,55)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,56) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,57)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,58) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,59)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,60) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,61)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,62) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,63)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,64) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,65)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,66) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,67)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,68) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,69)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,70) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,71)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,72) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,73)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,74) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,75)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,76) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,77)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,78) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,79)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,80) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,81)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,82) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,83)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,84) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,85)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,86) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,87)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,88) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,89)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,90) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,91)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,92) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,93)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,94) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,95)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,96) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,97)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,98) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,99))
)
AND  h3c_in_poly_convex($1,$2,$3);
' LANGUAGE SQL IMMUTABLE;

CREATE OR REPLACE FUNCTION h3c_poly_query(
                double precision, double precision,
                double precision[], integer)
                returns boolean as 'SELECT (
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,0,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,1,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,2,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,3,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,4,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,5,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,6,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,7,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,8,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,9,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,10,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,11,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,12,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,13,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,14,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,15,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,16,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,17,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,18,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,19,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,20,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,21,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,22,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,23,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,24,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,25,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,26,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,27,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,28,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,29,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,30,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,31,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,32,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,33,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,34,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,35,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,36,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,37,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,38,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,39,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,40,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,41,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,42,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,43,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,44,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,45,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,46,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,47,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,48,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,49,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,50,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,51,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,52,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,53,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,54,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,55,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,56,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,57,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,58,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,59,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,60,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,61,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,62,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,63,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,64,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,65,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,66,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,67,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,68,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,69,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,70,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,71,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,72,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,73,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,74,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,75,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,76,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,77,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,78,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,79,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,80,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,81,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,82,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,83,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,84,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,85,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,86,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,87,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,88,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,89,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,90,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,91,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,92,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,93,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,94,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,95,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,96,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,97,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,98,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,99,$4))
)
AND  h3c_in_poly_convex($1,$2,$3);
' LANGUAGE SQL IMMUTABLE;

CREATE OR REPLACE FUNCTION h3c_poly_convex_query(
                double precision, double precision,
                double precision[])
                returns boolean as 'SELECT (
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,0) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,2) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,3)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,4) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,5)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,6) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,7)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,8) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,9)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,10) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,11)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,12) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,13)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,14) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,15)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,16) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,17)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,18) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,19)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,20) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,21)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,22) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,23)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,24) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,25)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,26) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,27)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,28) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,29)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,30) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,31)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,32) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,33)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,34) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,35)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,36) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,37)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,38) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,39)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,40) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,41)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,42) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,43)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,44) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,45)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,46) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,47)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,48) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,49)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,50) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,51)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,52) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,53)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,54) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,55)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,56) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,57)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,58) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,59)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,60) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,61)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,62) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,63)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,64) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,65)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,66) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,67)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,68) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,69)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,70) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,71)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,72) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,73)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,74) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,75)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,76) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,77)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,78) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,79)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,80) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,81)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,82) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,83)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,84) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,85)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,86) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,87)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,88) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,89)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,90) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,91)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,92) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,93)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,94) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,95)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,96) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,97)) OR
(h3c_ang2ipix($1,$2)>=h3c_poly_query_it($3,98) AND h3c_ang2ipix($1,$2)<=h3c_poly_query_it($3,99))
)
AND  h3c_in_poly_convex($1,$2,$3)
' LANGUAGE SQL IMMUTABLE;

CREATE OR REPLACE FUNCTION h3c_poly_convex_query(
                double precision, double precision,
                double precision[], integer)
                returns boolean as 'SELECT (
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,0,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,1,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,2,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,3,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,4,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,5,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,6,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,7,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,8,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,9,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,10,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,11,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,12,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,13,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,14,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,15,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,16,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,17,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,18,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,19,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,20,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,21,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,22,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,23,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,24,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,25,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,26,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,27,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,28,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,29,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,30,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,31,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,32,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,33,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,34,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,35,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,36,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,37,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,38,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,39,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,40,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,41,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,42,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,43,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,44,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,45,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,46,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,47,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,48,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,49,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,50,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,51,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,52,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,53,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,54,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,55,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,56,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,57,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,58,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,59,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,60,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,61,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,62,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,63,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,64,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,65,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,66,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,67,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,68,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,69,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,70,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,71,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,72,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,73,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,74,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,75,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,76,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,77,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,78,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,79,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,80,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,81,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,82,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,83,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,84,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,85,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,86,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,87,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,88,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,89,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,90,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,91,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,92,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,93,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,94,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,95,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,96,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,97,$4)) OR
(h3c_ang2ipix($1,$2,$4)>=h3c_poly_query_it($3,98,$4) AND h3c_ang2ipix($1,$2,$4)<=h3c_poly_query_it($3,99,$4))
)
AND  h3c_in_poly_convex($1,$2,$3)
' LANGUAGE SQL IMMUTABLE;

/*
CREATE OR REPLACE FUNCTION h3c_box_query(
                double precision, double precision,
                double precision, double precision, 
                double precision, double precision)
                returns boolean as 'SELECT (
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,0) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,1)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,2) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,3)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,4) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,5)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,6) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,8) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,9)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,10) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,11)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,12) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,13)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,14) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,15)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,16) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,17)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,18) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,19)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,20) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,21)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,22) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,23)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,24) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,25)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,26) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,27)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,28) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,29)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,30) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,31)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,32) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,33)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,34) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,35)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,36) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,37)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,38) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,39)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,40) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,41)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,42) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,43)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,44) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,45)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,46) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,47)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,48) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,49)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,50) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,51)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,52) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,53)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,54) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,55)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,56) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,57)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,58) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,59)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,60) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,61)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,62) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,63)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,64) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,65)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,66) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,67)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,68) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,69)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,70) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,71)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,72) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,73)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,74) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,75)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,76) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,77)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,78) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,79)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,80) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,81)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,82) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,83)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,84) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,85)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,86) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,87)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,88) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,89)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,90) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,91)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,92) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,93)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,94) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,95)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,96) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,97)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,98) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,99))
)
AND  h3c_in_box($1,$2,$3,$4,$5,$6)
' LANGUAGE SQL IMMUTABLE;

CREATE OR REPLACE FUNCTION h3c_box_query(
                double precision, double precision,
                double precision, double precision, 
                double precision, double precision, integer)
                returns boolean as 'SELECT (
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,0,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,1,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,2,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,3,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,4,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,5,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,6,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,7,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,8,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,9,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,10,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,11,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,12,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,13,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,14,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,15,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,16,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,17,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,18,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,19,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,20,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,21,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,22,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,23,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,24,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,25,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,26,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,27,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,28,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,29,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,30,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,31,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,32,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,33,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,34,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,35,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,36,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,37,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,38,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,39,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,40,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,41,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,42,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,43,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,44,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,45,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,46,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,47,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,48,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,49,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,50,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,51,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,52,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,53,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,54,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,55,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,56,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,57,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,58,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,59,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,60,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,61,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,62,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,63,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,64,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,65,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,66,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,67,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,68,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,69,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,70,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,71,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,72,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,73,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,74,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,75,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,76,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,77,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,78,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,79,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,80,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,81,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,82,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,83,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,84,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,85,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,86,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,87,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,88,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,89,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,90,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,91,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,92,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,93,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,94,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,95,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,96,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,97,$7)) OR
(h3c_ang2ipix($1,$2)>=h3c_box_query_it($3,$4,$5,$6,98,$7) AND h3c_ang2ipix($1,$2)<=h3c_box_query_it($3,$4,$5,$6,99,$7))
)
AND  h3c_in_box($1,$2,$3,$4,$5,$6)
' LANGUAGE SQL IMMUTABLE;
*/

CREATE OR REPLACE FUNCTION h3c_circle_area(double precision)
	RETURNS double precision
        AS '$libdir/h3c', 'pgh3c_circle_area'
        LANGUAGE C IMMUTABLE STRICT;

CREATE OR REPLACE FUNCTION h3c_poly_area(double precision[])
	RETURNS double precision
        AS '$libdir/h3c', 'pgh3c_poly_area'
        LANGUAGE C IMMUTABLE STRICT;


CREATE OR REPLACE FUNCTION h3c_ipix2default_it(bigint, integer, integer)
	RETURNS bigint
        AS '$libdir/h3c', 'pgh3c_ipix2default_it'
        LANGUAGE C IMMUTABLE STRICT;

CREATE OR REPLACE FUNCTION h3c_ipix_query(double precision, double precision, bigint, integer)
	RETURNS boolean AS 'SELECT
h3c_ang2ipix($1,$2)>=h3c_ipix2default_it($3,$4,0) AND h3c_ang2ipix($1,$2)<=h3c_ipix2default_it($3,$4,1)
' LANGUAGE SQL IMMUTABLE;
END;

