/*
	   Copyright (C) 2012 Gilles Landais (CDS)

    Author: Gilles Landais, Strasbourg astronomical Data Center (CDS)
    Email: gilles.landais@unistra.fr

    This file is part of H3C.

    H3C is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    H3C is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with H3C; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

/** @file h3c_util.h
 *  @brief usefull functions in the library heaplix for PostgreSQL
 *  @author G.Landais (CDS)
 *  @date 19/jul/2011
 *
 *  @note this file contains __cplusplus macro to be used with C and C++
 */

#ifndef H3C_UTIL_H
#define H3C_UTIL_H

/* define nside */
#ifndef H3C_DEFAULT_NSIDE
#define H3C_DEFAULT_NSIDE 32768
#endif

/* define number of blocks used for cone search */
#ifndef H3C_DEFAULT_MEM_BLOCK
#define H3C_DEFAULT_MEM_BLOCK 100
#endif

/* define number of blocks used for xmatch */
#ifndef H3C_DEFAULT_NEARBY_MEM_BLOCK
#define H3C_DEFAULT_NEARBY_MEM_BLOCK 8
#endif

/* define the maximum of ipix memorized */
#ifndef H3C_DEFAULT_MAX_IPIX 
#define H3C_DEFAULT_MAX_IPIX 2000000
#endif

#define H3C_DEBUG DEBUG1
#define H3C_INFO  INFO
#define H3C_ERROR ERROR

#define H3C_STEP_ALLOC 50
#define H3C_LIST(a,n) n = H3C_STEP_ALLOC; \
a = (h3c_ipix_t *)malloc(sizeof(h3c_ipix_t)*H3C_STEP_ALLOC);
#define H3C_PUSH(a,b,c,val) if ((++b)%H3C_STEP_ALLOC == 0){\
if (c > H3C_DEFAULT_MAX_IPIX) h3c_log(H3C_ERROR, "too much ipix: abort");\
c += H3C_STEP_ALLOC; a=(h3c_ipix_t*)realloc(a, sizeof(h3c_ipix_t)*c);}\
(a)[(b)-1] = val;

#ifdef __cplusplus
extern "C" {
#endif
        /* function's declarations */
        void h3c_debug_init_clock();
        void h3c_log(int level, char *fmt, ...);
        h3c_coord_t h3c_theta2dec(h3c_coord_t);
        h3c_coord_t h3c_dec2theta(h3c_coord_t);
        h3c_coord_t h3c_phi2ra(h3c_coord_t);
        h3c_coord_t h3c_ra2phi(h3c_coord_t);
        int h3c_order(int nside);
        h3c_ipix_t h3c_npix(int nside);
        h3c_coord_t h3c_radius(int nside);

        int h3c_get_order_old(int nside);
        int h3c_number_ipix_old(int nside);
        h3c_coord_t h3c_radius_old(int nside);

        h3c_ipix_t *h3c_disk_ipix(h3c_coord_t, h3c_coord_t, h3c_coord_t, int, int *) ;
        int h3c_disk_ipix_it(h3c_coord_t, h3c_coord_t, h3c_coord_t, int, h3c_ipix_t *, int);
        h3c_coord_t h3c_dist(h3c_coord_t, h3c_coord_t, h3c_coord_t, h3c_coord_t);
        h3c_coord_t h3c_sindist(h3c_coord_t, h3c_coord_t, h3c_coord_t, h3c_coord_t);
        h3c_ipix_t *h3c_polygon_ipix(h3c_coord_t *, h3c_coord_t *, int, int, int *);
        int h3c_polygon_ipix_it(h3c_coord_t *, h3c_coord_t *, int, int, h3c_ipix_t *, int);
        char h3c_in_ellipse(h3c_coord_t, h3c_coord_t, h3c_coord_t, h3c_coord_t, h3c_coord_t, h3c_coord_t, h3c_coord_t);
        int h3c_poly_is_convex(int n, h3c_coord_t *, h3c_coord_t *);
        int h3c_check_sphere_circle_intersect_poly(int n, h3c_coord_t in_ra[], h3c_coord_t in_dec[], 
                                                   h3c_coord_t ra0, h3c_coord_t dec0, h3c_coord_t radius);
        int h3c_check_poly_intersect_poly(int n1,
                                  h3c_coord_t in_ra1[],
                                  h3c_coord_t in_dec1[],
                                  int n2,
                                  h3c_coord_t in_ra2[],
                                  h3c_coord_t in_dec2[]);
        h3c_coord_t h3c_polygon_area(h3c_coord_t *in_ra, h3c_coord_t *in_dec, int n);
        void h3c_box_2_polygon(h3c_coord_t in_ra, h3c_coord_t in_dec,
                               h3c_coord_t width, h3c_coord_t height,
                               h3c_coord_t poly_ra[4], h3c_coord_t poly_dec[4]);
        void h3c_pix2ang_nest(long nside, h3c_ipix_t ipnest, h3c_coord_t *theta, h3c_coord_t *phi);
        void h3c_ang2pix_nest(long nside, h3c_coord_t theta, h3c_coord_t phi, h3c_ipix_t *ipnest);
        void h3c_ring2nest(long nside, h3c_ipix_t ipring, h3c_ipix_t *ipnest);

        h3c_ipix_t *h3c_query_disc (h3c_coord_t ra, h3c_coord_t dec, h3c_coord_t radius, int nside, int *count);
#ifdef __cplusplus
}
#endif


#endif


